Crate bevy_mod_kira

Crate bevy_mod_kira 

Structs

KiraContext
KiraContext is a non-send resource that provides access to an initialized kira::AudioManager. Storing this in a non-send resource is necessary in order to support environments such as web (WebAssembly) and Android where kira’s AudioManager is non-sync. For simplicity’s sake the context is stored in a non-send resource everywhere.
KiraDebugPlugin
KiraPlaySoundEvent
This event is used to tell KiraPlugin to play a sound. Once KiraPlugin has consumed the event it will request that kira begins playing it. The sound handle for the playing event will be converted into a KiraPlayingSound and inserted into a KiraPlayingSounds (notice the KiraPlayingSounds in a system.
KiraPlayingSounds
This Component represents a collection of all currently playing sounds for an entity. The sounds can be iterated over using the static_handles and dynamic_handles methods.
KiraPlugin
KiraStaticSoundHandle
KiraTrackHandle
StaticSoundFileLoader

Enums

KiraPlayingSound

Traits

DynamicSoundHandle
A trait that allows communication with a dynamic sound that is currently playing.
KiraPlayable
KiraPlayable is a trait that allows KiraPlugin to play static (sounds loaded from a supported sound file) and dynamic sounds implementations of kira::sound::Sound.

Type Aliases

KiraStaticSoundAsset